@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Completion::PerinciCmdLine;
 
-our $DATE = '2014-11-23'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2014-11-29'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -68,6 +68,17 @@ run C<bash-completion-prog> and the C<complete> command will be added to your
 C<~/.bash-completion-prog>. Your next shell session will then recognize tab
 completion for the command.
 
+$h2 fish
+
+To activate fish completion for this script, execute:
+
+ begin; set -lx COMP_SHELL fish; set -lx COMP_MODE gen_command; $command_name; end > \$HOME/.config/fish/completions/$command_name.fish
+
+Or if you want to install globally, you can instead write the generated script
+to C</etc/fish/completions/$command_name.fish> or
+C</usr/share/fish/completions/$command_name.fish>. The exact path might be
+different on your system. Please check your C<fish_complete_path> variable.
+
 $h2 tcsh
 
 To activate tcsh completion for this script, put:
@@ -119,7 +130,7 @@ Pod::Weaver::Section::Completion::PerinciCmdLine - Add a COMPLETION section for
 
 =head1 VERSION
 
-This document describes version 0.05 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2014-11-23.
+This document describes version 0.06 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2014-11-29.
 
 =head1 SYNOPSIS
 
